@@ -9,39 +9,40 @@ Properties <- R6Class("Properties",
     #' @param closure One of "open", "half-open", or "closed."
     #' @param cardinality If non-`NULL` then either an integer, "Aleph0", or a Beth number.
     #' @return A new `Properties` object.
-    initialize = function(closure = character(0), cardinality = NULL){
+    initialize = function(closure = character(0), cardinality = NULL) {
 
-      if(length(closure) != 0){
+      if (length(closure) != 0) {
         checkmate::assertChoice(closure, c("open", "half-open", "closed"))
-        private$.closure = closure
+        private$.closure <- closure
       }
 
-      if(!is.null(cardinality)){
-        if (!(class(cardinality) %in% c("integer","numeric"))){
+      if (!is.null(cardinality)) {
+        if (!(class(cardinality) %in% c("integer", "numeric"))) {
           if (grepl("^a(leph){0,1}0$", cardinality, ignore.case = TRUE)) {
-            private$.cardinality = "Aleph0"
-            private$.countability = "countably infinite"
+            private$.cardinality <- "Aleph0"
+            private$.countability <- "countably infinite"
           } else if (grepl("^b(eth){0,1}[0-9]+$", cardinality, ignore.case = TRUE)) {
-            if(nchar(cardinality) < 5)
-              private$.cardinality = paste0("Beth", substr(cardinality, 2, 100))
-            else
-              private$.cardinality = paste0("Beth", substr(cardinality, 5, 100))
-            private$.countability = "uncountable"
+            if (nchar(cardinality) < 5) {
+              private$.cardinality <- paste0("Beth", substr(cardinality, 2, 100))
+            } else {
+              private$.cardinality <- paste0("Beth", substr(cardinality, 5, 100))
+            }
+            private$.countability <- "uncountable"
           } else {
             stop("Cardinality must either be a number or in {'Aleph0', 'A0', 'BethX', 'BX'} for some number X (case-insensitive)")
           }
         } else {
-          private$.cardinality = cardinality
+          private$.cardinality <- cardinality
 
           if (cardinality == Inf) {
-            private$.countability = "uncountable"
+            private$.countability <- "uncountable"
           } else {
-            private$.countability = "countably finite"
+            private$.countability <- "countably finite"
           }
         }
 
-        private$.empty = (cardinality == 0)
-        private$.singleton = (cardinality == 1)
+        private$.empty <- (cardinality == 0)
+        private$.singleton <- (cardinality == 1)
       }
 
       invisible(self)
@@ -50,35 +51,43 @@ Properties <- R6Class("Properties",
     #' @description
     #' Prints the `Properties` list.
     #' @return Prints `Properties` list to console.
-    print = function(){
+    print = function() {
       print(self$strprint())
     },
 
     #' @description
     #' Creates a printable representation of the `Properties`.
     #' @return A `list` of properties.
-    strprint = function(){
-      if(useUnicode() & length(self$cardinality) != 0){
-        if(self$cardinality == "Aleph0")
-          cardinality = "\u2135\u2080"
-        else if(class(self$cardinality) != "character")
-          cardinality = self$cardinality
-        else{
-          .beths = data.frame(X = 0:9, U = c("\u2080", "\u2081", "\u2082", "\u2083", "\u2084", "\u2085",
-                                             "\u2086", "\u2087", "\u2088", "\u2089"))
+    strprint = function() {
+      if (useUnicode() & length(self$cardinality) != 0) {
+        if (self$cardinality == "Aleph0") {
+          cardinality <- "\u2135\u2080"
+        } else if (class(self$cardinality) != "character") {
+          cardinality <- self$cardinality
+        } else {
+          .beths <- data.frame(X = 0:9, U = c(
+            "\u2080", "\u2081", "\u2082", "\u2083", "\u2084", "\u2085",
+            "\u2086", "\u2087", "\u2088", "\u2089"
+          ))
 
-          cardinality = paste0("\u2136", paste0(.beths$U[match(unlist(strsplit(substr(self$cardinality,
-                                                                                      5, 100), split = "")),
-                                                               .beths$X)], collapse = ""))
+          cardinality <- paste0("\u2136", paste0(.beths$U[match(
+            unlist(strsplit(substr(
+              self$cardinality,
+              5, 100
+            ), split = "")),
+            .beths$X
+          )], collapse = ""))
         }
-      } else
-        cardinality = self$cardinality
+      } else {
+        cardinality <- self$cardinality
+      }
 
-      list(empty = self$empty,
-           singleton = self$singleton,
-           cardinality = cardinality,
-           countability = self$countability,
-           closure = self$closure
+      list(
+        empty = self$empty,
+        singleton = self$singleton,
+        cardinality = cardinality,
+        countability = self$countability,
+        closure = self$closure
       )
     }
   ),
@@ -86,23 +95,33 @@ Properties <- R6Class("Properties",
   active = list(
     #' @field closure
     #' Returns the closure of the `Set`. One of "open", "half-open", or "closed."
-    closure = function() return(private$.closure),
+    closure = function() {
+      return(private$.closure)
+    },
 
     #' @field countability
     #' Returns the countability of the `Set`. One of "countably finite", "countably infinite", or "uncountable".
-    countability = function() return(private$.countability),
+    countability = function() {
+      return(private$.countability)
+    },
 
     #' @field cardinality
     #' Returns the cardinality of the `Set`. Either an integer if the `Set` is countably finite, Aleph0 if countably infinite, or a Beth number.
-    cardinality = function() return(private$.cardinality),
+    cardinality = function() {
+      return(private$.cardinality)
+    },
 
     #' @field empty
     #' Returns if the `Set` is empty or not. `TRUE` if the Set cardinality is `0`, `FALSE` otherwise.
-    empty = function() return(private$.empty),
+    empty = function() {
+      return(private$.empty)
+    },
 
     #' @field singleton
     #' Returns if the `Set` is a singleton or not. `TRUE` if the Set cardinality is `1`, `FALSE` otherwise.
-    singleton = function() return(private$.singleton)
+    singleton = function() {
+      return(private$.singleton)
+    }
   ),
 
   private = list(
