@@ -2,7 +2,8 @@
 #' @rdname SetWrapper
 #' @title Abstract SetWrapper Class
 #' @description This class should not be constructed directly. Parent class to `SetWrapper`s.
-SetWrapper <- R6Class("SetWrapper", inherit = Set,
+SetWrapper <- R6Class("SetWrapper",
+  inherit = Set,
   public = list(
     #' @description Create a new `SetWrapper` object. It is not recommended to construct this class directly.
     #' @param setlist List of [Set]s to wrap.
@@ -13,19 +14,21 @@ SetWrapper <- R6Class("SetWrapper", inherit = Set,
     #' @param cardinality character or integer. Cardinality of wrapper.
     #' @return A new `SetWrapper` object.
     initialize = function(setlist, lower = NULL, upper = NULL, type = NULL,
-                          class = NULL, cardinality){
-      if(getR6Class(self) == "SetWrapper")
+                          class = NULL, cardinality) {
+      if (getR6Class(self) == "SetWrapper") {
         stop(paste(getR6Class(self), "is an abstract class that can't be initialized."))
+      }
 
-      private$.wrappedSets <-  assertSetList(setlist)
+      private$.wrappedSets <- assertSetList(setlist)
 
-      if(!is.null(lower)) private$.lower <- lower
-      if(!is.null(upper)) private$.upper <- upper
-      if(!is.null(type)) private$.type <- type
+      if (!is.null(lower)) private$.lower <- lower
+      if (!is.null(upper)) private$.upper <- upper
+      if (!is.null(type)) private$.type <- type
 
       class <- rsapply(setlist, class, active = TRUE)
-      if(length(unique(class)) == 1)
+      if (length(unique(class)) == 1) {
         private$.class <- unique(class)
+      }
 
       private$.properties <- Properties$new(closure = "closed", cardinality)
 
@@ -37,20 +40,22 @@ SetWrapper <- R6Class("SetWrapper", inherit = Set,
     #' @return If `all == TRUE` then returns `TRUE` if all `x` are equal to `self`, otherwise `FALSE`.
     #' If `all == FALSE` returns a vector of logicals corresponding to the length of `x`, representing
     #' if each is equal to `self`.
-    equals = function(x, all = FALSE){
+    equals = function(x, all = FALSE) {
       x <- listify(x)
 
-      ret = sapply(x, function(el){
-        if(getR6Class(el) != getR6Class(self))
+      ret <- sapply(x, function(el) {
+        if (getR6Class(el) != getR6Class(self)) {
           return(FALSE)
+        }
 
-        if(length(self$wrappedSets) != length(el$wrappedSets))
+        if (length(self$wrappedSets) != length(el$wrappedSets)) {
           return(FALSE)
+        }
 
-        ret = TRUE
-        for(i in 1:length(self$wrappedSets)){
-          if(self$wrappedSets[[i]] != el$wrappedSets[[i]]){
-            ret = FALSE
+        ret <- TRUE
+        for (i in 1:length(self$wrappedSets)) {
+          if (self$wrappedSets[[i]] != el$wrappedSets[[i]]) {
+            ret <- FALSE
             break()
           }
         }
@@ -66,7 +71,7 @@ SetWrapper <- R6Class("SetWrapper", inherit = Set,
     #' @return If `all == TRUE` then returns `TRUE` if all `x` are (proper) subsets of `self`, otherwise `FALSE`.
     #' If `all == FALSE` returns a vector of logicals corresponding to the length of `x`, representing
     #' if each is a (proper) subset of `self`.
-    isSubset = function(x, proper = FALSE, all = FALSE){
+    isSubset = function(x, proper = FALSE, all = FALSE) {
       message("isSubset currently not implemented for this wrapper.")
     }
   ),
@@ -74,7 +79,7 @@ SetWrapper <- R6Class("SetWrapper", inherit = Set,
   active = list(
     #' @field wrappedSets
     #' Returns the list of `Set`s that are wrapped in the given wrapper.
-    wrappedSets = function(){
+    wrappedSets = function() {
       return(private$.wrappedSets)
     }
   ),
