@@ -2,8 +2,8 @@ library(testthat)
 
 test_that("construction", {
   expect_silent(LogicalSet$new())
-  l = LogicalSet$new()
-  s = Set$new(TRUE, FALSE)
+  l <- LogicalSet$new()
+  s <- Set$new(TRUE, FALSE)
   expect_equal(l$elements, s$elements)
   expect_equal(l$min, s$min)
   expect_equal(l$max, s$max)
